library(TESS)
library(phylosim)
library(ape)

#This simulates two sets of 100 birth death trees. Trees in the 
#first set - the 'broom' set - have a crown age of 25. Trees in the second
# set - the 'bush' set - have a crown age of 40. Trees in the first set have
# slightly higher net diversification rates, and slighlty more volatile
# diversificaiton dynamics than those in the second set -- i.e.,
# lambda1 - mu1 > lambda2 - mu2, and mu1 > mu2.
#Root edge lengths are assigned to trees in each set such that the stem
#node age is the same across trees in both sets. Then broom-bush pairs are
#grafted together at their root nodes, and gradfted trees with more than 
# 50 leaf nodes are filtered out.

brooms <- sim.globalBiDe.age(n=100, age=25, 0.11, 0.05, MRCA=TRUE)
trees <- sim.globalBiDe.age(n=100, age=40, 0.07, 0.03, MRCA=TRUE)


long.root <- function(x) {
    x$root.edge <- 20
    return(x)
    }

short.root <- function(x) {
    x$root.edge <- 5
    return(x)
    }

tatoo <- function(x) {
    x$tip.label <- paste("Broom", x$tip.label, sep="_")
    return(x)
    }

bikini <- function(x) {
    if (length(x$tip.label) < 50 & length(x$tip.label) > 10){
        return(x)
        }
    }

brooms <- lapply(brooms, long.root)
brooms <- lapply(brooms, tatoo)
#test.tree$tip.label <- paste("TT", test.tree$tip.label, sep="_")
trees <- lapply(trees, short.root)

bar <- cbind(trees, brooms)

grafts <- list()
for (i in 1:100){
    smut <- bind.tree(bar[[i,1]], bar[[i,2]], position=5)
    grafts[[i]] <- smut
    }
    
grooms <- lapply(grafts, bikini)
wiskers <- grooms[!sapply(grooms, is.null)]
