library(phylosim)
library(phangorn)

#This reads trees generated by the broom-and-bush-bd.R script.
#Tip labels in the broom subclade start with 'Broom_'.
#One thousand character DNA sequence datasets are simulated
#under GTR + G onto the broom and bush subtrees from the same 
#root sequence, but with the scaling factor on the bush subtree simulation
# an order of magnitude higher than it is for the broom simulation.

p<-GTR(rate.params=list( "a"=1, "b"=2, "c"=3, "d"=1, "e"=2, "f"=3 ), base.freqs=c(2,2,1,1)/6 )

trees <- read.tree('broomy-trees.tre')

for (i in 1:10){
	cat(paste('\nGrowing data on tree ', i, '\n\n',sep=''))
	
	t <- trees[[i]]
	broom.mrca <- 1
	bush.mrca <- 1
	rut <- mrca(t)['t1', 'Broom_t1']
	kids <- Children(t, rut)
	one.kid <- Descendants(t, kids[1], 'tips')
	poke <- t$tip.label[one.kid[[1]][1]]
	if (length(grep('Broom', poke))!=0){
		broom.mrca <- kids[1]
		bush.mrca <- kids[2]
		} else {
		broom.mrca <- kids[2]
		bush.mrca <- kids[1]
		}
		
	t.broom <- extract.clade(t, broom.mrca)
	t.broom$root.edge <- 20
	t.bush <- extract.clade(t, bush.mrca)
	t.bush$root.edge <- 5
	
	root.seq <- NucleotideSequence(length=1000,processes=list(list(p)))
	root.seq <- sampleStates(root.seq)
	
	cat('First the broom.\n')
	plusGamma(root.seq, p, 1)
	qmat <- getQMatrix(p)
	Scale(qmat, .001)
	sim<-PhyloSim(root.seq=root.seq, phylo=t.broom)
	Simulate(sim)
	handle = sprintf('broom_%s.fa', i)
	saveAlignment(sim,file=handle)
	
	cat('Then the bush.\n')
	plusGamma(root.seq, p, 1)
	qmat <- getQMatrix(p)
	Scale(qmat, .01)
	sim<-PhyloSim(root.seq=root.seq, phylo=t.bush)
	Simulate(sim)
	handle = sprintf('bush_%s.fa', i)
	saveAlignment(sim,file=handle)
}